==> docs_sdk_archive_luna-sdk_alma_rel_v.5.31.2.zip: docs_sdk_archive_luna-sdk_alma_rel_v.5.31.2/luna-sdk_alma_rel_v.5.31.2/doc/fsdk/html/search/variables_8.js <==
var searchData=
[
  ['index',['index',['../structfsdk_1_1_search_result.html#a01dc475d417c24d5a5d21f3d5b4fd4bb',1,'fsdk::SearchResult']]],
  ['infraredscore',['infraredScore',['../structfsdk_1_1_image_color_estimation.html#ac165d270012908634c78b652cf6bc68c',1,'fsdk::ImageColorEstimation']]],
  ['iris',['iris',['../structfsdk_1_1_eyes_estimation_1_1_eye_attributes.html#a085c2eba493874a622cb58249534fc5b',1,'fsdk::EyesEstimation::EyeAttributes']]],
  ['irislandmarkscount',['irisLandmarksCount',['../structfsdk_1_1_eyes_estimation_1_1_eye_attributes.html#afbab26b288e95a01a6a9829eacd3eaa6',1,'fsdk::EyesEstimation::EyeAttributes']]],
  ['isbeige',['isBeige',['../structfsdk_1_1_human_attribute_result_1_1_outwear_color_estimation.html#a77fe4f8525b218606f8f1eb235652733',1,'fsdk::HumanAttributeResult::OutwearColorEstimation']]],
  ['isblack',['isBlack',['../structfsdk_1_1_human_attribute_result_1_1_outwear_color_estimation.html#aaba2b79ff0e67b7877676d3390107c6c',1,'fsdk::HumanAttributeResult::OutwearColorEstimation::isBlack()'],['../structfsdk_1_1_human_attribute_result_1_1_apparent_color_estimation.html#af681898411da5e73c05e73ec0a38da9e',1,'fsdk::HumanAttributeResult::ApparentColorEstimation::isBlack()']]],
  ['isblue',['isBlue',['../structfsdk_1_1_human_attribute_result_1_1_outwear_color_estimation.html#a2ce70915b052b135797b24d5ea9c65cf',1,'fsdk::HumanAttributeResult::OutwearColorEstimation']]],
  ['isbrown',['isBrown',['../structfsdk_1_1_human_attribute_result_1_1_outwear_color_estimation.html#a2b1c79e84a5f8eca1e519a32070a8af7',1,'fsdk::HumanAttributeResult::OutwearColorEstimation']]],
  ['isgreen',['isGreen',['../structfsdk_1_1_human_attribute_result_1_1_outwear_color_estimation.html#ad135fd7f67908155d42e73b16fcf93ab',1,'fsdk::HumanAttributeResult::OutwearColorEstimation']]],
  ['isgrey',['isGrey',['../structfsdk_1_1_human_attribute_result_1_1_outwear_color_estimation.html#a2de3eab5d617e5e6d57d85e8fa8282ec',1,'fsdk::HumanAttributeResult::OutwearColorEstimation']]],
  ['iskhaki',['isKhaki',['../structfsdk_1_1_human_attribute_result_1_1_outwear_color_estimation.html#a12c552353c513820d564b893d0de28b2',1,'fsdk::HumanAttributeResult::OutwearColorEstimation']]],
  ['ismulticolored',['isMulticolored',['../structfsdk_1_1_human_attribute_result_1_1_outwear_color_estimation.html#a0a912b9a804cc39d0752c4fa19287a62',1,'fsdk::HumanAttributeResult::OutwearColorEstimation']]],
  ['isoccluded',['isOccluded',['../structfsdk_1_1_mouth_estimation.html#a4865f51c0af731ce29deb84dda29ada7',1,'fsdk::MouthEstimation::isOccluded()'],['../structfsdk_1_1_mouth_estimation_extended.html#affca41f7d6ea042f102a3dd812676e7d',1,'fsdk::MouthEstimationExtended::isOccluded()']]],
  ['isopened',['isOpened',['../structfsdk_1_1_mouth_estimation.html#a35ffacffd583cadd092a2a8b7a9f1a36',1,'fsdk::MouthEstimation::isOpened()'],['../structfsdk_1_1_mouth_estimation_extended.html#af31c38c678e7d0102d1f6e1d745e0999',1,'fsdk::MouthEstimationExtended::isOpened()']]],
  ['isorange',['isOrange',['../structfsdk_1_1_human_attribute_result_1_1_outwear_color_estimation.html#a96366eb5874a4c592a97a830a4396bdc',1,'fsdk::HumanAttributeResult::OutwearColorEstimation']]],
  ['isother',['isOther',['../structfsdk_1_1_human_attribute_result_1_1_apparent_color_estimation.html#a0491c68bee5c73a62f17f3c17a5dbbca',1,'fsdk::HumanAttributeResult::ApparentColorEstimation']]],
  ['ispink',['isPink',['../structfsdk_1_1_human_attribute_result_1_1_outwear_color_estimation.html#ae8fdb33cd67b491362d3a0e4688d9c5c',1,'fsdk::HumanAttributeResult::OutwearColorEstimation']]],
  ['ispurple',['isPurple',['../structfsdk_1_1_human_attribute_result_1_1_outwear_color_estimation.html#a110bfdb9732a17c7500440f4416c6335',1,'fsdk::HumanAttributeResult::OutwearColorEstimation']]],
  ['isreal',['isReal',['../structfsdk_1_1_depth_liveness_estimation.html#abdea3e3bc6b215ac3dbe1a01884ea2ba',1,'fsdk::DepthLivenessEstimation::isReal()'],['../structfsdk_1_1_depth_estimation.html#ad877c19fff20cde018fe08527d61bfa7',1,'fsdk::DepthEstimation::isReal()'],['../structfsdk_1_1_liveness_flying_faces_estimation.html#aea6ce92c9ffad83bcd16bbbc4f41b3a5',1,'fsdk::LivenessFlyingFacesEstimation::isReal()'],['../structfsdk_1_1_liveness_f_p_r_estimation.html#aa740485001e5ebe227c23fc632a797cf',1,'fsdk::LivenessFPREstimation::isReal()'],['../structfsdk_1_1_liveness_r_g_b_m_estimation.html#a9100113ca70f77351a31f3eb3cc2f2ff',1,'fsdk::LivenessRGBMEstimation::isReal()']]],
  ['isred',['isRed',['../structfsdk_1_1_human_attribute_result_1_1_outwear_color_estimation.html#ad6c68d3fd764a59feaaa4b5d85bd2834',1,'fsdk::HumanAttributeResult::OutwearColorEstimation']]],
  ['issmiling',['isSmiling',['../structfsdk_1_1_mouth_estimation.html#a577ff000dbb3177deb9c2a7ec4f802d0',1,'fsdk::MouthEstimation::isSmiling()'],['../structfsdk_1_1_mouth_estimation_extended.html#ab81bab2057bf8832de1355247696a8e7',1,'fsdk::MouthEstimationExtended::isSmiling()']]],
  ['isunknown',['isUnknown',['../structfsdk_1_1_human_attribute_result_1_1_apparent_color_estimation.html#a93b5e8810d054ccffa142d152b8345d9',1,'fsdk::HumanAttributeResult::ApparentColorEstimation']]],
  ['iswhite',['isWhite',['../structfsdk_1_1_human_attribute_result_1_1_outwear_color_estimation.html#ae9e77a2c9cc7582f618d76c52f259c7b',1,'fsdk::HumanAttributeResult::OutwearColorEstimation::isWhite()'],['../structfsdk_1_1_human_attribute_result_1_1_apparent_color_estimation.html#addff60391abfab467fd998a414fa8e6b',1,'fsdk::HumanAttributeResult::ApparentColorEstimation::isWhite()']]],
  ['isyellow',['isYellow',['../structfsdk_1_1_human_attribute_result_1_1_outwear_color_estimation.html#aba2cd841fcdaef282435c164fcebb27f',1,'fsdk::HumanAttributeResult::OutwearColorEstimation']]]
];

==> docs_sdk_archive_luna-sdk_alma_rel_v.5.32.0.zip: docs_sdk_archive_luna-sdk_alma_rel_v.5.32.0/luna-sdk_alma_rel_v.5.32.0/doc/fsdk/html/search/variables_8.js <==
var searchData=
[
  ['index',['index',['../structfsdk_1_1_search_result.html#a01dc475d417c24d5a5d21f3d5b4fd4bb',1,'fsdk::SearchResult']]],
  ['infraredscore',['infraredScore',['../structfsdk_1_1_image_color_estimation.html#ac165d270012908634c78b652cf6bc68c',1,'fsdk::ImageColorEstimation']]],
  ['iris',['iris',['../structfsdk_1_1_eyes_estimation_1_1_eye_attributes.html#a085c2eba493874a622cb58249534fc5b',1,'fsdk::EyesEstimation::EyeAttributes']]],
  ['irislandmarkscount',['irisLandmarksCount',['../structfsdk_1_1_eyes_estimation_1_1_eye_attributes.html#afbab26b288e95a01a6a9829eacd3eaa6',1,'fsdk::EyesEstimation::EyeAttributes']]],
  ['isbeige',['isBeige',['../structfsdk_1_1_human_attribute_result_1_1_outwear_color_estimation.html#a77fe4f8525b218606f8f1eb235652733',1,'fsdk::HumanAttributeResult::OutwearColorEstimation']]],
  ['isblack',['isBlack',['../structfsdk_1_1_human_attribute_result_1_1_outwear_color_estimation.html#aaba2b79ff0e67b7877676d3390107c6c',1,'fsdk::HumanAttributeResult::OutwearColorEstimation::isBlack()'],['../structfsdk_1_1_human_attribute_result_1_1_apparent_color_estimation.html#af681898411da5e73c05e73ec0a38da9e',1,'fsdk::HumanAttributeResult::ApparentColorEstimation::isBlack()']]],
  ['isblue',['isBlue',['../structfsdk_1_1_human_attribute_result_1_1_outwear_color_estimation.html#a2ce70915b052b135797b24d5ea9c65cf',1,'fsdk::HumanAttributeResult::OutwearColorEstimation']]],
  ['isbrown',['isBrown',['../structfsdk_1_1_human_attribute_result_1_1_outwear_color_estimation.html#a2b1c79e84a5f8eca1e519a32070a8af7',1,'fsdk::HumanAttributeResult::OutwearColorEstimation']]],
  ['isgreen',['isGreen',['../structfsdk_1_1_human_attribute_result_1_1_outwear_color_estimation.html#ad135fd7f67908155d42e73b16fcf93ab',1,'fsdk::HumanAttributeResult::OutwearColorEstimation']]],
  ['isgrey',['isGrey',['../structfsdk_1_1_human_attribute_result_1_1_outwear_color_estimation.html#a2de3eab5d617e5e6d57d85e8fa8282ec',1,'fsdk::HumanAttributeResult::OutwearColorEstimation']]],
  ['iskhaki',['isKhaki',['../structfsdk_1_1_human_attribute_result_1_1_outwear_color_estimation.html#a12c552353c513820d564b893d0de28b2',1,'fsdk::HumanAttributeResult::OutwearColorEstimation']]],
  ['ismulticolored',['isMulticolored',['../structfsdk_1_1_human_attribute_result_1_1_outwear_color_estimation.html#a0a912b9a804cc39d0752c4fa19287a62',1,'fsdk::HumanAttributeResult::OutwearColorEstimation']]],
  ['isoccluded',['isOccluded',['../structfsdk_1_1_mouth_estimation.html#a4865f51c0af731ce29deb84dda29ada7',1,'fsdk::MouthEstimation::isOccluded()'],['../structfsdk_1_1_mouth_estimation_extended.html#affca41f7d6ea042f102a3dd812676e7d',1,'fsdk::MouthEstimationExtended::isOccluded()']]],
  ['isopened',['isOpened',['../structfsdk_1_1_mouth_estimation.html#a35ffacffd583cadd092a2a8b7a9f1a36',1,'fsdk::MouthEstimation::isOpened()'],['../structfsdk_1_1_mouth_estimation_extended.html#af31c38c678e7d0102d1f6e1d745e0999',1,'fsdk::MouthEstimationExtended::isOpened()']]],
  ['isorange',['isOrange',['../structfsdk_1_1_human_attribute_result_1_1_outwear_color_estimation.html#a96366eb5874a4c592a97a830a4396bdc',1,'fsdk::HumanAttributeResult::OutwearColorEstimation']]],
  ['isother',['isOther',['../structfsdk_1_1_human_attribute_result_1_1_apparent_color_estimation.html#a0491c68bee5c73a62f17f3c17a5dbbca',1,'fsdk::HumanAttributeResult::ApparentColorEstimation']]],
  ['ispink',['isPink',['../structfsdk_1_1_human_attribute_result_1_1_outwear_color_estimation.html#ae8fdb33cd67b491362d3a0e4688d9c5c',1,'fsdk::HumanAttributeResult::OutwearColorEstimation']]],
  ['ispurple',['isPurple',['../structfsdk_1_1_human_attribute_result_1_1_outwear_color_estimation.html#a110bfdb9732a17c7500440f4416c6335',1,'fsdk::HumanAttributeResult::OutwearColorEstimation']]],
  ['isreal',['isReal',['../structfsdk_1_1_depth_liveness_estimation.html#abdea3e3bc6b215ac3dbe1a01884ea2ba',1,'fsdk::DepthLivenessEstimation::isReal()'],['../structfsdk_1_1_depth_estimation.html#ad877c19fff20cde018fe08527d61bfa7',1,'fsdk::DepthEstimation::isReal()'],['../structfsdk_1_1_liveness_flying_faces_estimation.html#aea6ce92c9ffad83bcd16bbbc4f41b3a5',1,'fsdk::LivenessFlyingFacesEstimation::isReal()'],['../structfsdk_1_1_liveness_r_g_b_m_estimation.html#a9100113ca70f77351a31f3eb3cc2f2ff',1,'fsdk::LivenessRGBMEstimation::isReal()']]],
  ['isred',['isRed',['../structfsdk_1_1_human_attribute_result_1_1_outwear_color_estimation.html#ad6c68d3fd764a59feaaa4b5d85bd2834',1,'fsdk::HumanAttributeResult::OutwearColorEstimation']]],
  ['issmiling',['isSmiling',['../structfsdk_1_1_mouth_estimation.html#a577ff000dbb3177deb9c2a7ec4f802d0',1,'fsdk::MouthEstimation::isSmiling()'],['../structfsdk_1_1_mouth_estimation_extended.html#ab81bab2057bf8832de1355247696a8e7',1,'fsdk::MouthEstimationExtended::isSmiling()']]],
  ['isunknown',['isUnknown',['../structfsdk_1_1_human_attribute_result_1_1_apparent_color_estimation.html#a93b5e8810d054ccffa142d152b8345d9',1,'fsdk::HumanAttributeResult::ApparentColorEstimation']]],
  ['iswhite',['isWhite',['../structfsdk_1_1_human_attribute_result_1_1_outwear_color_estimation.html#ae9e77a2c9cc7582f618d76c52f259c7b',1,'fsdk::HumanAttributeResult::OutwearColorEstimation::isWhite()'],['../structfsdk_1_1_human_attribute_result_1_1_apparent_color_estimation.html#addff60391abfab467fd998a414fa8e6b',1,'fsdk::HumanAttributeResult::ApparentColorEstimation::isWhite()']]],
  ['isyellow',['isYellow',['../structfsdk_1_1_human_attribute_result_1_1_outwear_color_estimation.html#aba2cd841fcdaef282435c164fcebb27f',1,'fsdk::HumanAttributeResult::OutwearColorEstimation']]]
];
